@@ -12,6 +12,7 @@ from pyaedt import settings
 from pyaedt.application.Analysis3DLayout import FieldAnalysis3DLayout
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import open_file
+from pyaedt.generic.general_methods import parse_excitation_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modules.Boundary import BoundaryObject3dLayout
 
@@ -526,9 +527,9 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         """
         layers = self.modeler.layers.all_signal_layers
         if not top_layer:
-            top_layer = layers[0]
+            top_layer = layers[0].name
         if not bot_layer:
-            bot_layer = layers[len(layers) - 1]
+            bot_layer = layers[len(layers) - 1].name
         self.modeler.oeditor.CreatePin(
             [
                 "NAME:Contents",
@@ -1219,9 +1220,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             return False
         active_project = self.project_name
         path_ext = os.path.splitext(cad_path)
-        project_name = os.path.splitext(os.path.basename(cad_path))[0]
         if not aedb_path:
             aedb_path = path_ext[0] + ".aedb"
+        project_name = os.path.splitext(os.path.basename(aedb_path))[0]
+
         if os.path.exists(aedb_path):
             old_name = project_name
             project_name = generate_unique_name(project_name)
@@ -1893,3 +1895,96 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             out_files.sort(key=lambda x: os.path.getmtime(x))
             return out_files[0]
         return ""
+
+    @pyaedt_function_handler()
+    def edit_source_from_file(
+        self,
+        source_name,
+        file_name,
+        is_time_domain=True,
+        x_scale=1,
+        y_scale=1,
+        impedance=50,
+        data_format="Power",
+        encoding="utf-8",
+        include_post_effects=True,
+        incident_voltage=True,
+    ):
+        """Edit a source from file data.
+        File data is a csv containing either frequency data or time domain data that will be converted through FFT.
+
+        Parameters
+        ----------
+        source_name : str
+            Source Name.
+        file_name : str
+            Full name of the input file.
+        is_time_domain : bool, optional
+            Either if the input data is Time based or Frequency Based. Frequency based data are Mag/Phase (deg).
+        x_scale : float, optional
+            Scaling factor for x axis.
+        y_scale : float, optional
+            Scaling factor for y axis.
+        impedance : float, optional
+            Excitation impedance. Default is `50`.
+        data_format : str, optional
+            Either `"Power"`, `"Current"` or `"Voltage"`.
+        encoding : str, optional
+            Csv file encoding.
+        include_post_effects : bool, optional
+            Either if include or not post-processing effects. Default is `True`,
+        incident_voltage : bool, optional
+            Either if include or incident or total voltage. Default is `True`, for incident voltage.
+
+
+        Returns
+        -------
+        bool
+        """
+        out = "Voltage"
+        freq, mag, phase = parse_excitation_file(
+            file_name=file_name,
+            is_time_domain=is_time_domain,
+            x_scale=x_scale,
+            y_scale=y_scale,
+            impedance=impedance,
+            data_format=data_format,
+            encoding=encoding,
+            out_mag=out,
+        )
+        ds_name_mag = "ds_" + source_name.replace(":", "_mode_") + "_Mag"
+        ds_name_phase = "ds_" + source_name.replace(":", "_mode_") + "_Angle"
+        if self.dataset_exists(ds_name_mag, False):
+            self.design_datasets[ds_name_mag].x = freq
+            self.design_datasets[ds_name_mag].y = mag
+            self.design_datasets[ds_name_mag].update()
+        else:
+            self.create_dataset1d_design(ds_name_mag, freq, mag, xunit="Hz")
+        if self.dataset_exists(ds_name_phase, False):
+            self.design_datasets[ds_name_phase].x = freq
+            self.design_datasets[ds_name_phase].y = phase
+            self.design_datasets[ds_name_phase].update()
+
+        else:
+            self.create_dataset1d_design(ds_name_phase, freq, phase, xunit="Hz", yunit="deg")
+        for p in self.boundaries:
+            if p.name == source_name:
+                str_val = ["TotalVoltage"]
+                if incident_voltage:
+                    str_val = ["IncidentVoltage"]
+                if include_post_effects:
+                    str_val.append("IncludePortPostProcess")
+                self.oboundary.EditExcitations(
+                    [
+                        "NAME:Excitations",
+                        [source_name, "pwl({}, Freq)".format(ds_name_mag), "pwl({}, Freq)".format(ds_name_phase)],
+                    ],
+                    ["NAME:Terminations", [source_name, False, str(impedance) + "ohm", "0ohm"]],
+                    ",".join(str_val),
+                    [],
+                )
+
+                self.logger.info("Source Excitation updated with Dataset.")
+                return True
+        self.logger.error("Port not found.")
+        return False
